@@ -20,8 +20,11 @@ The plugin handles two cases:
 
 =item A file being present with a name such as /etc/blacklist.d/1.2.3.4
 
+=item A file being present with a name such as $state/blacklist.d/1.2.3.4.
+
 =item An entry in /etc/blogspam/badips matching the incoming IP
 
+
 =back
 
 Note that the server administrator is responsible for populating the
@@ -162,6 +165,17 @@ sub testComment
         return "SPAM:badip:/etc/blacklist.d/$ip";
     }
 
+
+    #
+    #  Get our state directory.
+    #
+    my $state = $params{ 'parent' }->getStateDir();
+    my $cdir  = $state . "/blacklist.d/";
+    if ( -d $cdir && -e "$cdir/$ip" )
+    {
+        return "SPAM:badip:state/blacklist.d/$ip";
+    }
+
     #
     #  The source of bad IPs
     #
