@@ -57,6 +57,7 @@ use strict;
 use warnings;
 
 
+use Fcntl qw(:flock);
 use File::Path qw/mkpath/;
 use IPC::Open2;
 
@@ -158,6 +159,12 @@ sub testComment
     #
     my $comment = $params{ 'comment' } || "";
 
+    #
+    #  Create a lock
+    #
+    open( FILE, ">", $db . ".lock" );
+    flock( FILE, LOCK_EX );
+
     #
     #  Open the command for reading/writing.
     #
@@ -191,6 +198,12 @@ sub testComment
     #
     waitpid $pid, 0;
 
+    #
+    #  Unlock
+    #
+    flock( FILE, LOCK_UN );
+    close(FILE);
+
     #
     #  We'll not count an "unsure" result, so we're either
     # looking for a header of "ham" or "spam".
