@@ -1,4 +1,46 @@
 
+=head1 NAME
+
+Blog::Spam::Plugin::rdns - Reject content from hosts with no RDNS.
+
+=cut
+
+=head1 ABOUT
+
+This plugin is designed to discard comments which have been submitted
+by IP addresses with no reverse DNS entries defined.
+
+Although many home ADSL/broadband providers will configure reverse DNS
+of some generic form this plugin is liable to have a higher chance than
+most others of creating false-positives.
+
+=cut
+
+=head1 AUTHOR
+
+=over 4
+
+=item Steve Kemp
+
+http://www.steve.org.uk/
+
+=back
+
+=cut
+
+=head1 LICENSE
+
+Copyright (c) 2008-2010 by Steve Kemp.  All rights reserved.
+
+This module is free software;
+you can redistribute it and/or modify it under
+the same terms as Perl itself.
+The LICENSE file contains the full text of the license.
+
+=cut
+
+
+
 
 package Blog::Spam::Plugin::rdns;
 
@@ -34,6 +76,15 @@ sub new
     return $self;
 }
 
+
+=begin doc
+
+Return the name of this plugin.
+
+=end doc
+
+=cut
+
 sub name
 {
     my ($self) = (@_);
